//
// Entete de la classe fenetre secondaire type oscilloscope
//
#ifndef FOscGUI_h
#define FOscGUI_h

#include "TCanvas.h"
#include "TGClient.h"
#include "TGButton.h"
#include "TGTextEntry.h"
#include "TGComboBox.h"
#include "TGColorSelect.h"
#include "TRootEmbeddedCanvas.h"
#include "TGSlider.h"
#include "TGListBox.h"
#include "TGNumberEntry.h"
#include "TSortedList.h"
#include "TFile.h"
#include "TTree.h"
#include "TTimer.h"
#include "TGTab.h"
#include "TGLabel.h"
#include "FEventProcessorThread.h"
#include "MTELabel.h"
#include "MTNELabel.h"
#include "MCBLabel.h"
#include "MEmbeddedCanvasWithMarks.h"
#include "FOscilloH1F.h"

class FOscGUI : public TGMainFrame
{
	enum ElementId
	{
		B_Start,
		B_Pause,
		B_Continue,
		B_Stop,
		B_ClearSpectra,
		B_Sortie,
	};

	// Declaration des boutons de la fenetre principale
	public:
	TGPictureButton	*bRun, *bPause, *bStop, *bSortie, *bClearSpectra;
	TGLabel		*nbEvt;
	TGLabel		*runStatus;
	TTimer		*evtTimer;
	Int_t		oldNevt;
	TTimer		*refreshDSTimer;
	TGLabel		*openedConfig;
	TGTextButton	*loadConf;
	TTimer		*refreshCanvasTimer;
	TGTextButton 	*openExp;
	MEmbeddedCanvasWithMarks *oscCanvas;

	// Gestion du temps de rafraichissement
	TGNumberEntry *teRefTime;

	TGLayoutHints	*lAffichageB,*lAffichageA,*lAffichageC,*lAffichageF;

	private:
	FEventProcessorThread	*fept;
	TGTextButton *enableSignal1; 
	TGTextButton *enableSignal2; 
	MCBLabel 	*oscilloList1;
	MCBLabel 	*oscilloList2;
	FOscilloH1F *h1;
	FOscilloH1F *h2;
	TGNumberEntry *persistanceEntry1;
	TGNumberEntry *persistanceEntry2;
	TGTextButton *horizontalMode; 
	TGTextButton *verticalMode; 
	TGTextButton *setupMode; 
	Bool_t ch1IsEnabled;
	Bool_t ch2IsEnabled;
	Bool_t horizontalScale;
	Bool_t verticalScale;
	Bool_t modeControl;
	//char *confName;
	Double_t oldRefTime;
	Double_t refTime;

	public:
	FOscGUI(const TGWindow *p=0,UInt_t w=1600,UInt_t h=800);
	~FOscGUI();

	virtual FEventProcessorThread *GetFEventProcessorThread(void) { return fept;}
	virtual void SetFEventProcessorThread(FEventProcessorThread *f) { fept=f;}

  	virtual void SetListeOscillos(void);
	virtual Bool_t HandleTimer(TTimer *timer);
	virtual void AffNevt(void);

	virtual void StartProcessing(void);
	virtual void PauseProcessing(void);
	virtual void ClearSpectra(void);
	virtual void StopProcessing(void);
	virtual void Close(void);

	virtual void SetConfigName(char *confName);
	virtual void SetRefreshTime(void);
	virtual void RefreshEmbeddedCanvas(void);

	virtual void WarningBox(char const *title="Warning",char const *msg="Warning");
	virtual void ChangeSignal1State(void);
	virtual void ChangeSignal2State(void);	
	virtual void GetSignalName1(void);
	virtual void GetSignalName2(void);
	virtual void SetPersistance1(void);
	virtual void SetPersistance2(void);
	virtual void SetHorizontalCursors(void);
	virtual void SetVerticalCursors(void);
	virtual void SetModeControl(void);
	virtual void PrintOscillo(void);
	virtual void SaveOscillos(void);

	ClassDef(FOscGUI,1)
};

#endif
